@@ -67,7 +67,7 @@ class PlexusHook(BaseHook):
 
     @property
     def token(self) -> Any:
-        """Returns users token"""
+        """Returns users token."""
         if self.__token is not None:
             if not self.__token_exp or arrow.get(self.__token_exp) <= arrow.now():
                 self.__token = self._generate_token()
